pub fn init_fpu_check()Expand description
Initialize FPU check (call this early to trigger warning if needed)
This function triggers the lazy initialization which checks FPU state and prints a warning if dangerous settings are detected. The warning is only printed once per process.